<?php

namespace Modules\RolePermission\Providers;

use Illuminate\Support\ServiceProvider;
use Illuminate\Database\Eloquent\Factory;

class RolePermissionServiceProvider extends ServiceProvider
{

       /**
     * @var string $moduleName
     */
    protected $moduleName = 'RolePermission';

    /**
     * @var string $moduleNameLower
     */
    protected $moduleNameLower = 'rolepermission';
    /**
     * Boot the application events.
     *
     * @return void
     */
    public function boot()
    {
        $this->registerTranslations();
        $this->registerConfig();
        $this->registerViews();
        // $this->registerFactories();
        $this->loadMigrationsFrom(module_path('RolePermission', 'Database/Migrations'));
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->app->register(RouteServiceProvider::class);
    }

    /**
     * Register config.
     *
     * @return void
     */
    protected function registerConfig()
    {
        $this->publishes([
            module_path('RolePermission', 'Config/config.php') => config_path('rolepermission.php'),
        ], 'config');
        $this->mergeConfigFrom(
            module_path('RolePermission', 'Config/config.php'), 'rolepermission'
        );
    }

    /**
     * Register views.
     *
     * @return void
     */
    public function registerViews()
    {
        $viewPath = resource_path('views/modules/rolepermission');

        $sourcePath = module_path('RolePermission', 'Resources/views');

        $this->publishes([
            $sourcePath => $viewPath
        ],'views');

        $this->loadViewsFrom(array_merge(array_map(function ($path) {
            return $path . '/modules/rolepermission';
        }, \Config::get('view.paths')), [$sourcePath]), 'rolepermission');
    }

    /**
     * Register translations.
     *
     * @return void
     */
    public function registerTranslations()
    {
        $langPath = resource_path('lang/modules/rolepermission');

        if (is_dir($langPath)) {
            $this->loadTranslationsFrom($langPath, 'rolepermission');
        } else {
            $this->loadTranslationsFrom(module_path('RolePermission', 'Resources/lang'), 'rolepermission');
        }
    }

    /**
     * Register an additional directory of factories.
     *
     * @return void
     */
    public function registerFactories()
    {
        if (! app()->environment('production') && $this->app->runningInConsole()) {
            app(Factory::class)->load(module_path('RolePermission', 'Database/factories'));
        }
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return [];
    }
}
